@@ -60,8 +60,18 @@ class _CStatus(CtypesEnum):
     PRODUCER_SEND_ONEWAY_FAILED = 12
     PRODUCER_SEND_ORDERLY_FAILED = 13
     PRODUCER_SEND_ASYNC_FAILED = 14
+    PRODUCER_SEND_ORDERLYASYNC_FAILED = 15
+    PRODUCER_SEND_TRANSACTION_FAILED = 16
     # push consumer
+    PUSH_CONSUMER_ERROR_CODE_START = 20
     PUSH_CONSUMER_START_FAILED = 20
+    # pull consumer
+    PULL_CONSUMER_ERROR_CODE_START = 30
+    PULL_CONSUMER_START_FAILED = 30
+    PULL_CONSUMER_FETCH_MQ_FAILED = 31
+    PULL_CONSUMER_FETCH_MESSAGE_FAILED = 32
+
+    Not_Support = 500
 
     NOT_SUPPORT_NOW = -1
 
@@ -227,8 +237,18 @@ dll.CreateTransactionProducer.restype = c_void_p
 dll.SendMessageTransaction.argtypes = [c_void_p, c_void_p, LOCAL_TRANSACTION_EXECUTE_CALLBACK, c_void_p,
                                        POINTER(_CSendResult)]
 dll.SendMessageTransaction.restype = c_int
+dll.SetProducerMessageTrace.argtypes = [c_void_p, _CTraceModel]
+dll.SetProducerMessageTrace.restype = c_int
 dll.SetProducerLanguage.argtypes = [c_void_p, c_char_p]
 dll.SetProducerLanguage.restype = c_int
+dll.SetProducerLogPath.argtypes = [c_void_p, c_char_p]
+dll.SetProducerLogPath.restype = c_int
+dll.SetProducerAbsoluteLogPath.argtypes = [c_void_p, c_char_p]
+dll.SetProducerAbsoluteLogPath.restype = c_int
+dll.SetProducerLogFileNumAndSize.argtypes = [c_void_p, c_int, c_long]
+dll.SetProducerLogFileNumAndSize.restype = c_int
+dll.SetProducerLogLevel.argtypes = [c_void_p, _CLogLevel]
+dll.SetProducerLogLevel.restype = c_int
 
 # Push Consumer
 MSG_CALLBACK_FUNC = ctypes.CFUNCTYPE(c_int, c_void_p, c_void_p)
@@ -274,12 +294,20 @@ dll.SetPushConsumerLogLevel.argtypes = [c_void_p, _CLogLevel]
 dll.SetPushConsumerLogLevel.restype = _CStatus
 dll.SetPushConsumerMessageModel.argtypes = [c_void_p, MessageModel]
 dll.SetPushConsumerMessageModel.restype = _CStatus
-dll.SetPushConsumerLanguage.argtypes = [c_void_p, c_char_p]
-dll.SetPushConsumerLanguage.restype = c_int
-dll.SetPushConsumerConsumeFromWhere.argtypes = [c_void_p, _CConsumeFromWhere]
-dll.SetPushConsumerConsumeFromWhere.restype = _CStatus
 dll.SetPushConsumerMessageTrace.argtypes = [c_void_p, _CTraceModel]
 dll.SetPushConsumerMessageTrace.restype = c_int
+dll.SetPushConsumerLanguage.argtypes = [c_void_p, c_char_p]
+dll.SetPushConsumerLanguage.restype = c_int
+dll.SetPushConsumerLogPath.argtypes = [c_void_p, c_char_p]
+dll.SetPushConsumerLogPath.restype = c_int
+dll.SetPushConsumerAbsoluteLogPath.argtypes = [c_void_p, c_char_p]
+dll.SetPushConsumerAbsoluteLogPath.restype = c_int
+dll.SetPushConsumerConsumeFromWhere.argtypes = [c_void_p, _CConsumeFromWhere]
+dll.SetPushConsumerConsumeFromWhere.restype = _CStatus
+dll.SetPushConsumerLogFileNumAndSize.argtypes = [c_void_p, c_int, c_long]
+dll.SetPushConsumerLogFileNumAndSize.restype = c_int
+dll.SetPushConsumerLogLevel.argtypes = [c_void_p, _CLogLevel]
+dll.SetPushConsumerLogLevel.restype = c_int
 
 # Misc
 dll.GetLatestErrorMessage.argtypes = []
